@@ -832,8 +832,9 @@ struct Widget {
     pub options: Vec<(String, String)>, // Hint: <value, Title> - <option value="value1">Title 1</option>
     pub thumbnails: Vec<(String, u32)>,
     pub slug_sources: Vec<String>, // Example: r#"["title"]"# or r#"["title", "hash"]"#
-    pub other_attrs: String,       // "autofocus tabindex=\"some number\" size=\"some number\" ..."
-    pub css_classes: String,       // "class-name class-name ..."
+    pub is_hide: bool,
+    pub other_attrs: String, // "autofocus tabindex=\"some number\" size=\"some number\" ..."
+    pub css_classes: String, // "class-name class-name ..."
     pub hint: String,
     pub warning: String,    // The value is determined automatically
     pub error: String,      // The value is determined automatically
@@ -865,6 +866,7 @@ impl Default for Widget {
             options: Vec::new(),
             thumbnails: Vec::new(),
             slug_sources: Vec::new(),
+            is_hide: false,
             other_attrs: String::new(),
             css_classes: String::new(),
             hint: String::new(),
@@ -1554,6 +1556,18 @@ fn get_param_value<'a>(
                 )
             }
         }
+        "is_hide" => {
+            if let syn::Lit::Bool(lit_bool) = &mnv.lit {
+                widget.is_hide = lit_bool.value;
+            } else {
+                panic!(
+                    "Model: `{}` > Field: `{}` : \
+                    Could not determine value for parameter `is_hide`. \
+                    Example: true. Default = false.",
+                    model_name, field_name
+                )
+            }
+        }
         "other_attrs" => {
             if let syn::Lit::Str(lit_str) = &mnv.lit {
                 widget.other_attrs = lit_str.value().trim().to_string();
